@@ -1,5 +1,6 @@
 from .errors import WrongArgNumber
 
+
 class Continuation(object):
     def __init__(self, ctx, ip_displacement, n_pop):
         self.ctx = ctx.clone()
@@ -8,4 +9,4 @@ class Continuation(object):
             self.ctx.pop_n(n_pop)
 
     def __str__(self):
-        return '<Continuation ctx=%s>' % self.ctx
+        return "<Continuation ctx=%s>" % self.ctx
