@@ -1,14 +1,10 @@
-from types          import NoneType
-                      
+from ..errors import CompileError, SyntaxError
+from ..form import Form
+from ..macro import DynamicClosure, Macro, SymbolClosure
+from ..types.pair import Pair as pair
 from ..types.symbol import Symbol as sym
-from ..types.pair   import Pair as pair
-from ..macro        import Macro, DynamicClosure, SymbolClosure
-from ..form         import Form
-                     
-from ..errors       import CompileError
-from ..errors       import SyntaxError
+from .builder import Builder
 
-from .builder       import Builder
 
 class Compiler(object):
     """\
@@ -32,7 +28,7 @@ class Compiler(object):
     sym_cond = sym("cond")
     sym_call_cc = sym("call/cc")
     sym_call_cc2 = sym("call-with-current-continuation")
-    
+
     def __init__(self):
         self.label_seed = 0
 
@@ -52,11 +48,13 @@ class Compiler(object):
         dist = 0
         while descendant != ancestor:
             if descendant is None:
-                raise SyntaxError("Attempt calculate the distance between unrelated environments.")
+                raise SyntaxError(
+                    "Attempt calculate the distance between unrelated environments."
+                )
             dist += 1
             descendant = descendant.parent
         return dist
-        
+
     def get_macro(self, env, name):
         if not isinstance(name, sym):
             return None
@@ -67,13 +65,13 @@ class Compiler(object):
         if isinstance(val, Macro):
             return val
         return None
-    
+
     def self_evaluating(self, expr):
-        for t in [int, int, complex, float, str, str, bool, NoneType]:
+        for t in [int, int, complex, float, str, str, bool, type(None)]:
             if isinstance(expr, t):
                 return True
         return False
-        
+
     def next_label(self):
         self.label_seed += 1
         return "__lbl_%d" % self.label_seed
@@ -117,19 +115,19 @@ class Compiler(object):
             Compiler.sym_do: self.generate_do,
             Compiler.sym_cond: self.generate_cond,
             Compiler.sym_call_cc: self.generate_call_cc,
-            Compiler.sym_call_cc2: self.generate_call_cc
-            }
+            Compiler.sym_call_cc2: self.generate_call_cc,
+        }
         if self.self_evaluating(expr):
             if keep:
-                bdr.emit('push_literal', expr)
+                bdr.emit("push_literal", expr)
                 if tail:
-                    bdr.emit('ret')
-        
+                    bdr.emit("ret")
+
         elif isinstance(expr, sym):
             if keep:
                 bdr.emit_local("push", expr.name)
                 if tail:
-                    bdr.emit('ret')
+                    bdr.emit("ret")
 
         elif isinstance(expr, pair):
             routine = mapping.get(expr.first)
@@ -147,58 +145,60 @@ class Compiler(object):
                     self.generate_expr(form_bdr, expr, keep=True, tail=False)
                     macro_closure = DynamicClosure(transform_env, expr)
                     macro_closure.form = form_bdr.generate()
-                    bdr.emit('push_literal', macro_closure)
+                    bdr.emit("push_literal", macro_closure)
 
                     dist = self.calc_env_distance(macro.lexical_parent, bdr.env)
                     if dist == 0:
-                        bdr.emit('fix_lexical')
+                        bdr.emit("fix_lexical")
                     else:
-                        bdr.emit('fix_lexical_depth', dist)
+                        bdr.emit("fix_lexical_depth", dist)
 
                     # fix lexical parent of dynamic closures
                     for dc in dc_list:
-                        bdr.emit('push_literal', dc)
-                        bdr.emit('fix_lexical_pop')
+                        bdr.emit("push_literal", dc)
+                        bdr.emit("fix_lexical_pop")
                         form_bdr = Builder(bdr.env)
-                        self.generate_expr(form_bdr, dc.expression, keep=True, tail=False)
+                        self.generate_expr(
+                            form_bdr, dc.expression, keep=True, tail=False
+                        )
                         dc.form = form_bdr.generate()
 
-                    bdr.emit('dynamic_eval')
+                    bdr.emit("dynamic_eval")
                     if not keep:
-                        bdr.emit('pop')
+                        bdr.emit("pop")
                     elif tail:
-                        bdr.emit('ret')
-                        
+                        bdr.emit("ret")
+
                 else:
-                    arg  = expr.rest
+                    arg = expr.rest
                     while isinstance(arg, pair):
                         self.generate_expr(bdr, arg.first, keep=True, tail=False)
                         arg = arg.rest
                         argc += 1
                     self.generate_expr(bdr, expr.first, keep=True, tail=False)
-                    
+
                     if tail:
-                        bdr.emit('tail_call', argc)
+                        bdr.emit("tail_call", argc)
                     else:
-                        bdr.emit('call', argc)
+                        bdr.emit("call", argc)
                         if not keep:
-                            bdr.emit('pop')
+                            bdr.emit("pop")
 
         elif isinstance(expr, DynamicClosure):
-            bdr.emit('push_literal', expr)
-            bdr.emit('dynamic_eval')
+            bdr.emit("push_literal", expr)
+            bdr.emit("dynamic_eval")
             if not keep:
-                bdr.emit('pop')
+                bdr.emit("pop")
             elif tail:
-                bdr.emit('ret')
-            
+                bdr.emit("ret")
+
         else:
             raise CompileError("Expecting atom or list, but got %s" % expr)
 
     def generate_if_expr(self, bdr, expr, keep=True, tail=False):
         if expr is None:
             raise SyntaxError("Missing condition expression in 'if'")
-            
+
         cond = expr.first
         expthen = expr.rest
         if expthen is None:
@@ -216,30 +216,30 @@ class Compiler(object):
         if keep is True:
             lbl_then = self.next_label()
             lbl_end = self.next_label()
-            bdr.emit('goto_if_not_false', lbl_then)
+            bdr.emit("goto_if_not_false", lbl_then)
             if expelse is None:
-                bdr.emit('push_nil')
+                bdr.emit("push_nil")
                 if tail:
-                    bdr.emit('ret')
+                    bdr.emit("ret")
             else:
                 self.generate_expr(bdr, expelse, keep=True, tail=tail)
             if not tail:
-                bdr.emit('goto', lbl_end)
+                bdr.emit("goto", lbl_end)
             bdr.def_label(lbl_then)
             self.generate_expr(bdr, expthen, keep=True, tail=tail)
             bdr.def_label(lbl_end)
         else:
             if expelse is None:
                 lbl_end = self.next_label()
-                bdr.emit('goto_if_false', lbl_end)
+                bdr.emit("goto_if_false", lbl_end)
                 self.generate_expr(bdr, expthen, keep=False, tail=False)
                 bdr.def_label(lbl_end)
             else:
                 lbl_then = self.next_label()
                 lbl_end = self.next_label()
-                bdr.emit('goto_if_not_false', lbl_then)
+                bdr.emit("goto_if_not_false", lbl_then)
                 self.generate_expr(bdr, expelse, keep=False, tail=False)
-                bdr.emit('goto', lbl_end)
+                bdr.emit("goto", lbl_end)
                 bdr.def_label(lbl_then)
                 self.generate_expr(bdr, expthen, keep=False, tail=False)
                 bdr.def_label(lbl_end)
@@ -250,7 +250,7 @@ class Compiler(object):
         elif isinstance(expr, sym):
             return expr
         raise SyntaxError("Expecting symbol, but got %s" % expr)
-    
+
     def generate_lambda(self, base_builder, expr, keep=True, tail=False):
         if keep is not True:
             return  # lambda expression has no side-effect
@@ -278,12 +278,12 @@ class Compiler(object):
             bdr = base_builder.push_proc(args=args, rest_arg=rest_arg)
             self.generate_body(bdr, body, keep=True, tail=True)
             base_builder.emit("fix_lexical")
-            
+
             if tail:
-                base_builder.emit('ret')
+                base_builder.emit("ret")
 
         except AttributeError as e:
-            raise SyntaxError("Broken lambda expression: "+e.message)
+            raise SyntaxError("Broken lambda expression: " + e.message)
 
     def generate_let(self, bdr, expr, keep=True, tail=False):
         """\
@@ -302,34 +302,37 @@ class Compiler(object):
         if isinstance(bindings, pair):
             while isinstance(bindings, pair):
                 binding = bindings.first
-                if not isinstance(binding, pair) or \
-                   not isinstance(binding.rest, pair):
-                    raise SyntaxError("Invalid binding for let expression: %s" % binding)
+                if not isinstance(binding, pair) or not isinstance(binding.rest, pair):
+                    raise SyntaxError(
+                        "Invalid binding for let expression: %s" % binding
+                    )
                 param.append(self.filter_sc(binding.first).name)
                 args.append(binding.rest.first)
                 bindings = bindings.rest
         elif bindings is not None:
-            raise SyntaxError("Invalid let expression: expecting bindings, but got %s" % bindings)
+            raise SyntaxError(
+                "Invalid let expression: expecting bindings, but got %s" % bindings
+            )
 
         for x in args:
             self.generate_expr(bdr, x, keep=True, tail=False)
 
         lambda_bdr = bdr.push_proc(args=param, rest_arg=False)
         self.generate_body(lambda_bdr, expr.rest, keep=True, tail=True)
-        bdr.emit('fix_lexical')
+        bdr.emit("fix_lexical")
 
-        argc = len(args) 
+        argc = len(args)
         if tail:
-            bdr.emit('tail_call', argc)
+            bdr.emit("tail_call", argc)
         else:
-            bdr.emit('call', argc)
+            bdr.emit("call", argc)
             if not keep:
-                bdr.emit('pop')
+                bdr.emit("pop")
 
     def generate_letrec(self, bdr, expr, keep=True, tail=False):
         if not isinstance(expr, pair):
             raise SyntaxError("Invalid letrec expression")
-        
+
         bindings = expr.first
         body = expr.rest
 
@@ -338,12 +341,14 @@ class Compiler(object):
         # letrec will evaluate the init forms in the new env
         names = []
         vals = []
-        
+
         while isinstance(bindings, pair):
             binding = bindings.first
-            if not isinstance(binding, pair) or \
-               not isinstance(binding.first, sym) or \
-               not isinstance(binding.rest, pair):
+            if (
+                not isinstance(binding, pair)
+                or not isinstance(binding.first, sym)
+                or not isinstance(binding.rest, pair)
+            ):
                 raise SyntaxError("Invalid binding for letrec expression: %s" % binding)
             name = self.filter_sc(binding.first).name
             val = binding.rest.first
@@ -353,28 +358,28 @@ class Compiler(object):
             vals.append(val)
 
             bindings = bindings.rest
-        
+
         if bindings is not None:
             raise SyntaxError("Invalid bindings for letrec expression: %s" % bindings)
 
         for i in range(len(names)):
             self.generate_expr(lambda_bdr, vals[i], keep=True, tail=False)
-            lambda_bdr.emit_local('set', names[i])
+            lambda_bdr.emit_local("set", names[i])
 
         self.generate_body(lambda_bdr, body, keep=True, tail=True)
-        bdr.emit('fix_lexical')
+        bdr.emit("fix_lexical")
 
         if tail:
-            bdr.emit('tail_call', 0)
+            bdr.emit("tail_call", 0)
         else:
-            bdr.emit('call', 0)
+            bdr.emit("call", 0)
             if not keep:
-                bdr.emit('pop')
+                bdr.emit("pop")
 
     def generate_letstar(self, bdr, expr, keep=True, tail=False):
         if not isinstance(expr, pair):
             raise SyntaxError("Invalid letrec expression")
-        
+
         bindings = expr.first
         body = expr.rest
 
@@ -383,12 +388,14 @@ class Compiler(object):
         # let* will evaluate the init forms in the new env sequencially
         names = []
         vals = []
-        
+
         while isinstance(bindings, pair):
             binding = bindings.first
-            if not isinstance(binding, pair) or \
-               not isinstance(binding.first, sym) or \
-               not isinstance(binding.rest, pair):
+            if (
+                not isinstance(binding, pair)
+                or not isinstance(binding.first, sym)
+                or not isinstance(binding.rest, pair)
+            ):
                 raise SyntaxError("Invalid binding for let* expression: %s" % binding)
             name = self.filter_sc(binding.first).name
             val = binding.rest.first
@@ -397,26 +404,25 @@ class Compiler(object):
             vals.append(val)
 
             bindings = bindings.rest
-        
+
         if bindings is not None:
             raise SyntaxError("Invalid bindings for let* expression: %s" % bindings)
 
         for i in range(len(names)):
             lambda_bdr.def_local(names[i])
             self.generate_expr(lambda_bdr, vals[i], keep=True, tail=False)
-            lambda_bdr.emit_local('set', names[i])
+            lambda_bdr.emit_local("set", names[i])
 
         self.generate_body(lambda_bdr, body, keep=True, tail=True)
-        bdr.emit('fix_lexical')
+        bdr.emit("fix_lexical")
 
         if tail:
-            bdr.emit('tail_call', 0)
+            bdr.emit("tail_call", 0)
         else:
-            bdr.emit('call', 0)
+            bdr.emit("call", 0)
             if not keep:
-                bdr.emit('pop')
-        
-        
+                bdr.emit("pop")
+
     def generate_define(self, bdr, expr, keep=True, tail=False):
         if expr is None:
             raise SyntaxError("Empty define expression")
@@ -425,7 +431,7 @@ class Compiler(object):
         # SymbolClosure now has no effect, only as normal symbol
         if isinstance(var, SymbolClosure):
             var = var.expression
-        
+
         if isinstance(var, pair):
             gen = self.generate_lambda
             val = pair(var.rest, expr.rest)
@@ -446,10 +452,10 @@ class Compiler(object):
         bdr.def_local(var.name)
         gen(bdr, val, keep=True, tail=False)
         if keep is True:
-            bdr.emit('dup')
-        bdr.emit_local('set', var.name)
+            bdr.emit("dup")
+        bdr.emit_local("set", var.name)
         if tail:
-            bdr.emit('ret')
+            bdr.emit("ret")
 
     def generate_set_x(self, bdr, expr, keep=True, tail=False):
         if expr is None:
@@ -465,27 +471,27 @@ class Compiler(object):
 
         self.generate_expr(bdr, val, keep=True, tail=False)
         if keep:
-            bdr.emit('dup')
+            bdr.emit("dup")
 
         if isinstance(var, sym):
-            bdr.emit_local('set', var.name)
+            bdr.emit_local("set", var.name)
         elif isinstance(var, SymbolClosure):
-            bdr.emit('push_literal', var)
-            bdr.emit_local('set', var.expression.name, var.lexical_parent)
+            bdr.emit("push_literal", var)
+            bdr.emit_local("set", var.expression.name, var.lexical_parent)
         else:
             raise SyntaxError("Invalid set! expression, expecting symbol")
 
         if tail:
-            bdr.emit('ret')
+            bdr.emit("ret")
 
     def generate_quote(self, bdr, expr, keep=True, tail=False):
         expr = expr.first
         if isinstance(expr, DynamicClosure):
             expr = expr.expression
         if keep:
-            bdr.emit('push_literal', expr)
+            bdr.emit("push_literal", expr)
             if tail:
-                bdr.emit('ret')
+                bdr.emit("ret")
 
     def generate_or(self, bdr, expr, keep=True, tail=False):
         lbl_end = self.next_label()
@@ -499,19 +505,19 @@ class Compiler(object):
                 expr_generated = True
                 self.generate_expr(bdr, el, keep=True, tail=False)
                 if keep:
-                    bdr.emit('dup')
-                bdr.emit('goto_if_not_false', lbl_end)
+                    bdr.emit("dup")
+                bdr.emit("goto_if_not_false", lbl_end)
                 if keep:
                     if expr is not None:
-                        bdr.emit('pop')
+                        bdr.emit("pop")
         if expr is not None:
             raise SyntaxError("Invalid element in or expression: %s" % expr)
         if keep:
             if not expr_generated:
-                bdr.emit('push_false')
+                bdr.emit("push_false")
             if tail:
-                bdr.emit('ret')
-                
+                bdr.emit("ret")
+
         bdr.def_label(lbl_end)
 
     def generate_and(self, bdr, expr, keep=True, tail=False):
@@ -526,35 +532,39 @@ class Compiler(object):
                 expr_generated = True
                 self.generate_expr(bdr, el, keep=True, tail=False)
                 if keep:
-                    bdr.emit('dup')
-                bdr.emit('goto_if_false', lbl_end)
+                    bdr.emit("dup")
+                bdr.emit("goto_if_false", lbl_end)
                 if keep:
                     if expr is not None:
-                        bdr.emit('pop')
+                        bdr.emit("pop")
         if expr is not None:
             raise SyntaxError("Invalid element in or expression: %s" % expr)
         if keep:
             if not expr_generated:
-                bdr.emit('push_true')
+                bdr.emit("push_true")
             if tail:
-                bdr.emit('ret')
-                
+                bdr.emit("ret")
+
         bdr.def_label(lbl_end)
 
     def generate_define_syntax(self, bdr, expr, keep=True, tail=False):
         if not isinstance(expr, pair):
-            raise SyntaxError("Invalid define-syntax expression, expecting macro keyword")
+            raise SyntaxError(
+                "Invalid define-syntax expression, expecting macro keyword"
+            )
         name = expr.first
         if not isinstance(name, sym):
             raise SyntaxError("Expecting macro keyword as a symbol, but got %s" % name)
         expr = expr.rest
-        if not isinstance(expr, pair) or \
-               not isinstance(expr.first, pair) or \
-               Compiler.sym_syntax_rules != expr.first.first:
+        if (
+            not isinstance(expr, pair)
+            or not isinstance(expr.first, pair)
+            or Compiler.sym_syntax_rules != expr.first.first
+        ):
             raise SyntaxError("Expecting syntax-rules, but got %s" % expr.first)
         if expr.rest is not None:
             raise SyntaxError("Extra expressions in define-syntax: %s" % expr.rest)
-        
+
         # define local before constructing the macro, so that recursive macro
         # can be supported
         idx = bdr.def_local(name.name)
@@ -564,9 +574,9 @@ class Compiler(object):
         if keep:
             # macro object is generally not available at runtime, the value of
             # 'define-syntax' expression is None
-            bdr.emit('push_nil')
+            bdr.emit("push_nil")
             if tail:
-                bdr.emit('ret')
+                bdr.emit("ret")
 
     def generate_do(self, bdr, expr, keep=True, tail=False):
         if not isinstance(expr, pair):
@@ -574,8 +584,7 @@ class Compiler(object):
         init_spec = expr.first
 
         expr = expr.rest
-        if not isinstance(expr, pair) or \
-           not isinstance(expr.first, pair):
+        if not isinstance(expr, pair) or not isinstance(expr.first, pair):
             raise SyntaxError("Invalid do expression, expecting (<test> <result>)")
 
         test_expr = expr.first.first
@@ -587,8 +596,7 @@ class Compiler(object):
         steps = []
         while isinstance(init_spec, pair):
             spec = init_spec.first
-            if not isinstance(spec, pair) or \
-               not isinstance(spec.rest, pair):
+            if not isinstance(spec, pair) or not isinstance(spec.rest, pair):
                 raise SyntaxError("Invalid init spec for do expression: %s" % spec)
             var = self.filter_sc(spec.first)
             if not isinstance(var, sym):
@@ -604,7 +612,7 @@ class Compiler(object):
             init_spec = init_spec.rest
         if init_spec is not None:
             raise SyntaxError("Invalid init specs for do expression")
-            
+
         for val in init_vals:
             self.generate_expr(bdr, val, keep=True, tail=False)
 
@@ -614,28 +622,28 @@ class Compiler(object):
 
         lam_bdr.def_label(lbl_test)
         self.generate_expr(lam_bdr, test_expr, keep=True, tail=False)
-        lam_bdr.emit('goto_if_not_false', lbl_end)
+        lam_bdr.emit("goto_if_not_false", lbl_end)
         self.generate_body(lam_bdr, body, keep=False, tail=False)
 
         for i in range(len(steps)):
             if steps[i] is not None:
                 self.generate_expr(lam_bdr, steps[i], keep=True, tail=False)
-        for i in range(len(steps)-1, -1, -1):
+        for i in range(len(steps) - 1, -1, -1):
             if steps[i] is not None:
-                lam_bdr.emit_local('set', variables[i])
+                lam_bdr.emit_local("set", variables[i])
 
-        lam_bdr.emit('goto', lbl_test)
+        lam_bdr.emit("goto", lbl_test)
         lam_bdr.def_label(lbl_end)
         self.generate_body(lam_bdr, result_expr, keep=True, tail=True)
 
-        bdr.emit('fix_lexical')
+        bdr.emit("fix_lexical")
 
         if tail:
-            bdr.emit('tail_call', len(variables))
+            bdr.emit("tail_call", len(variables))
         else:
-            bdr.emit('call', len(variables))
+            bdr.emit("call", len(variables))
             if not keep:
-                bdr.emit('pop')
+                bdr.emit("pop")
 
     def generate_cond(self, bdr, expr, keep=True, tail=False):
         if not isinstance(expr, pair):
@@ -650,9 +658,9 @@ class Compiler(object):
             lbl_next = self.next_label()
 
             if not first:
-                bdr.emit('pop')
+                bdr.emit("pop")
                 first = False
-            
+
             cond_expr = expr.first
             if not isinstance(cond_expr, pair):
                 raise SyntaxError("Invalid cond clause: %s" % cond_expr)
@@ -661,64 +669,70 @@ class Compiler(object):
 
             expr = expr.rest
 
-            if pred == sym('else'):
+            if pred == sym("else"):
                 if body is None:
-                    bdr.emit('push_true')
+                    bdr.emit("push_true")
                 else:
                     if not isinstance(body, pair):
                         raise SyntaxError("Invalid cond clause: %s" % cond_expr)
-                    if body.first == sym('=>'):
+                    if body.first == sym("=>"):
                         if not isinstance(body.rest, pair):
-                            raise SyntaxError("Invalid cond clause, expecting expression after =>")
-                        bdr.emit('push_true')
+                            raise SyntaxError(
+                                "Invalid cond clause, expecting expression after =>"
+                            )
+                        bdr.emit("push_true")
                         self.generate_expr(bdr, body.rest.first, keep=True, tail=False)
-                        bdr.emit('call', 1)
+                        bdr.emit("call", 1)
                     else:
                         self.generate_body(bdr, body, keep=True, tail=False)
                 break
-            
+
             else:
                 self.generate_expr(bdr, pred, keep=True, tail=False)
                 if body is None:
-                    bdr.emit('dup')
-                    bdr.emit('goto_if_false', lbl_next)
+                    bdr.emit("dup")
+                    bdr.emit("goto_if_false", lbl_next)
                 else:
                     if not isinstance(body, pair):
                         raise SyntaxError("Invalid cond clause: %s" % cond_expr)
-                    if body.first == sym('=>'):
+                    if body.first == sym("=>"):
                         if not isinstance(body.rest, pair):
-                            raise SyntaxError("Invalid cond clause, expecting expression after =>")
-                        bdr.emit('dup')
-                        bdr.emit('goto_if_false', lbl_next)
+                            raise SyntaxError(
+                                "Invalid cond clause, expecting expression after =>"
+                            )
+                        bdr.emit("dup")
+                        bdr.emit("goto_if_false", lbl_next)
                         self.generate_expr(bdr, body.rest.first, keep=True, tail=False)
-                        bdr.emit('call', 1)
+                        bdr.emit("call", 1)
                     else:
-                        bdr.emit('goto_if_false', lbl_next)
+                        bdr.emit("goto_if_false", lbl_next)
                         self.generate_body(bdr, body, keep=True, tail=False)
-                bdr.emit('goto', lbl_end)
-                    
+                bdr.emit("goto", lbl_end)
+
         if expr is not None:
             raise SyntaxError("Extra garbage expression in cond expression: %s" % expr)
-        
+
         bdr.def_label(lbl_next)
-        bdr.emit('push_nil')
+        bdr.emit("push_nil")
         bdr.def_label(lbl_end)
 
         if not keep:
-            bdr.emit('pop')
+            bdr.emit("pop")
         if tail:
-            bdr.emit('ret')
+            bdr.emit("ret")
 
     def generate_call_cc(self, bdr, expr, keep=True, tail=False):
         if not isinstance(expr, pair):
             raise SyntaxError("Empty call/cc expression")
         if expr.rest is not None:
-            raise SyntaxError("call/cc only takes one argument, but got extra %s" % expr.rest)
+            raise SyntaxError(
+                "call/cc only takes one argument, but got extra %s" % expr.rest
+            )
 
         lam = expr.first
         self.generate_expr(bdr, lam, keep=True, tail=False)
-        bdr.emit('call_cc')
+        bdr.emit("call_cc")
         if tail:
-            bdr.emit('ret')
+            bdr.emit("ret")
         if not keep:
-            bdr.emit('pop')
+            bdr.emit("pop")
